==> gnome.ldtp-1.0.0-20120309.162952-8.jar: ldtp_api.clj <==
[("activatetext" [["window_name" "object_name"] 0])
 ("activatewindow" [["window_name"] 0])
 ("appendtext" [["window_name" "object_name" "data"] 1])
 ("check" [["window_name" "object_name"] 0])
 ("checkrow" [["window_name" "object_name" "row_index" "column"] 1])
 ("click" [["window_name" "object_name"] 0])
 ("closewindow" [["window_name"] 1])
 ("comboselect" [["window_name" "object_name" "item_name"] 0])
 ("comboselectindex" [["window_name" "object_name" "item_index"] 0])
 ("copytext"
  [["window_name" "object_name" "start_position" "end_position"] 1])
 ("cuttext"
  [["window_name" "object_name" "start_position" "end_position"] 1])
 ("decrease" [["window_name" "object_name" "iterations"] 0])
 ("deletetext"
  [["window_name" "object_name" "start_position" "end_position"] 1])
 ("doesmenuitemexist" [["window_name" "object_name"] 0])
 ("doesrowexist" [["window_name" "object_name" "row_text"] 0])
 ("doubleclick" [["window_name" "object_name"] 0])
 ("doubleclickrow" [["window_name" "object_name" "row_text"] 0])
 ("enterstring" [["window_name" "object_name" "data"] 2])
 ("expandtablecell"
  [["window_name" "object_name" "row_index" "column"] 1])
 ("generatekeyevent" [["data"] 0])
 ("generatemouseevent" [["x" "y" "eventType"] 1])
 ("getallitem" [["window_name" "object_name"] 0])
 ("getallstates" [["window_name" "object_name"] 0])
 ("getapplist" [[] 0])
 ("getcellvalue"
  [["window_name" "object_name" "row_index" "column"] 1])
 ("getcharcount" [["window_name" "object_name"] 0])
 ("getchild" [["window_name" "child_name" "role" "parent"] 3])
 ("getcursorposition" [["window_name" "object_name"] 0])
 ("getmax" [["window_name" "object_name"] 0])
 ("getmaxvalue" [["window_name" "object_name"] 0])
 ("getminincrement" [["window_name" "object_name"] 0])
 ("getminvalue" [["window_name" "object_name"] 0])
 ("getobjectinfo" [["window_name" "object_name"] 0])
 ("getobjectlist" [["window_name"] 0])
 ("getobjectproperty" [["window_name" "object_name" "prop"] 0])
 ("getobjectsize" [["window_name" "object_name"] 0])
 ("getrowcount" [["window_name" "object_name"] 0])
 ("getslidervalue" [["window_name" "object_name"] 0])
 ("getstatusbartext" [["window_name" "object_name"] 0])
 ("gettabcount" [["window_name" "object_name"] 0])
 ("gettablerowindex" [["window_name" "object_name" "row_text"] 0])
 ("gettabname" [["window_name" "object_name" "tab_index"] 0])
 ("gettextvalue"
  [["window_name" "object_name" "startPosition" "endPosition"] 2])
 ("getvalue" [["window_name" "object_name"] 0])
 ("getwindowlist" [[] 0])
 ("getwindowsize" [["window_name"] 0])
 ("grabfocus" [["window_name" "object_name"] 0])
 ("guiexist" [["window_name" "object_name"] 1])
 ("hasstate" [["window_name" "object_name" "state" "guiTimeOut"] 1])
 ("hidelist" [["window_name" "object_name"] 0])
 ("imagecapture" [["window_name" "x" "y" "width" "height"] 5])
 ("increase" [["window_name" "object_name" "iterations"] 0])
 ("invokemenu" [["window_name" "object_name"] 0])
 ("isalive" [[] 0])
 ("ischildindexselected"
  [["window_name" "object_name" "item_index"] 0])
 ("ischildselected" [["window_name" "object_name" "item_name"] 0])
 ("istextstateenabled" [["window_name" "object_name"] 0])
 ("keypress" [["data"] 0])
 ("keyrelease" [["data"] 0])
 ("launchapp" [["cmd" "args" "delay" "env"] 3])
 ("listsubmenus" [["window_name" "object_name"] 0])
 ("maximizewindow" [["window_name"] 1])
 ("menucheck" [["window_name" "object_name"] 0])
 ("menuitemenabled" [["window_name" "object_name"] 0])
 ("menuuncheck" [["window_name" "object_name"] 0])
 ("minimizewindow" [["window_name"] 1])
 ("mouseleftclick" [["window_name" "object_name"] 0])
 ("mousemove" [["window_name" "object_name"] 0])
 ("mouserightclick" [["window_name" "object_name"] 0])
 ("objectexist" [["window_name" "object_name"] 0])
 ("onedown" [["window_name" "object_name" "iterations"] 0])
 ("oneleft" [["window_name" "object_name" "iterations"] 0])
 ("oneright" [["window_name" "object_name" "iterations"] 0])
 ("oneup" [["window_name" "object_name" "iterations"] 0])
 ("onwindowcreate" [["window_name"] 0])
 ("pastetext" [["window_name" "object_name" "position"] 1])
 ("poll_events" [[] 0])
 ("press" [["window_name" "object_name"] 0])
 ("registerevent" [["event_name"] 0])
 ("remap" [["window_name"] 0])
 ("removecallback" [["window_name"] 0])
 ("removeevent" [["event_name"] 0])
 ("scrolldown" [["window_name" "object_name"] 0])
 ("scrollleft" [["window_name" "object_name"] 0])
 ("scrollright" [["window_name" "object_name"] 0])
 ("scrollup" [["window_name" "object_name"] 0])
 ("selectall" [["window_name" "object_name"] 0])
 ("selecteditemcount" [["window_name" "object_name"] 0])
 ("selectindex" [["window_name" "object_name" "item_index"] 0])
 ("selectitem" [["window_name" "object_name" "item_name"] 0])
 ("selectlastrow" [["window_name" "object_name"] 0])
 ("selectmenuitem" [["window_name" "object_name"] 0])
 ("selectrow" [["window_name" "object_name" "row_text"] 0])
 ("selectrowindex" [["window_name" "object_name" "row_index"] 0])
 ("selectrowpartialmatch" [["window_name" "object_name" "row_text"] 0])
 ("selecttab" [["window_name" "object_name" "tab_name"] 0])
 ("selecttabindex" [["window_name" "object_name" "tab_index"] 0])
 ("setcellvalue"
  [["window_name" "object_name" "row_index" "column" "data"] 2])
 ("setcursorposition"
  [["window_name" "object_name" "cursor_position"] 0])
 ("setlocale" [["locale_str"] 0])
 ("setmax" [["window_name" "object_name"] 0])
 ("setmin" [["window_name" "object_name"] 0])
 ("settextvalue" [["window_name" "object_name" "data"] 1])
 ("setvalue" [["window_name" "object_name" "data"] 0])
 ("showlist" [["window_name" "object_name"] 0])
 ("simulatemousemove"
  [["source_x" "source_y" "dest_x" "dest_y" "delay"] 1])
 ("singleclickrow" [["window_name" "object_name" "row_text"] 0])
 ("stateenabled" [["window_name" "object_name"] 0])
 ("uncheck" [["window_name" "object_name"] 0])
 ("uncheckrow" [["window_name" "object_name" "row_index" "column"] 1])
 ("unmaximizewindow" [["window_name"] 1])
 ("unminimizewindow" [["window_name"] 1])
 ("unselectall" [["window_name" "object_name"] 0])
 ("unselectindex" [["window_name" "object_name" "item_index"] 0])
 ("unselectitem" [["window_name" "object_name" "item_name"] 0])
 ("verifycheck" [["window_name" "object_name"] 0])
 ("verifydropdown" [["window_name" "object_name"] 0])
 ("verifyhidelist" [["window_name" "object_name"] 0])
 ("verifymenucheck" [["window_name" "object_name"] 0])
 ("verifymenuuncheck" [["window_name" "object_name"] 0])
 ("verifypartialmatch"
  [["window_name" "object_name" "partial_text"] 0])
 ("verifypartialtablecell"
  [["window_name" "object_name" "row_index" "column_index" "row_text"]
   0])
 ("verifyscrollbarhorizontal" [["window_name" "object_name"] 0])
 ("verifyscrollbarvertical" [["window_name" "object_name"] 0])
 ("verifyselect" [["window_name" "object_name" "item_name"] 0])
 ("verifysettext" [["window_name" "object_name" "text"] 0])
 ("verifysetvalue" [["window_name" "object_name" "data"] 0])
 ("verifyshowlist" [["window_name" "object_name"] 0])
 ("verifysliderhorizontal" [["window_name" "object_name"] 0])
 ("verifyslidervertical" [["window_name" "object_name"] 0])
 ("verifytablecell"
  [["window_name" "object_name" "row_index" "column_index" "row_text"]
   0])
 ("verifytabname" [["window_name" "object_name" "tab_name"] 0])
 ("verifytoggled" [["window_name" "object_name"] 0])
 ("verifyuncheck" [["window_name" "object_name"] 0])
 ("wait" [["timeout"] 1])
 ("waittillguiexist"
  [["window_name" "object_name" "guiTimeOut" "state"] 3])
 ("waittillguinotexist" [["window_name" "object_name" "guiTimeOut"] 2])
 ("windowuptime" [["window_name"] 0])]

==> gnome.ldtp-1.1.0-20121205.213844-3.jar: ldtp_api.clj <==
[("activatetext" [["window_name" "object_name"] 0])
 ("activatewindow" [["window_name"] 0])
 ("appendtext" [["window_name" "object_name" "data"] 0])
 ("check" [["window_name" "object_name"] 0])
 ("checkrow" [["window_name" "object_name" "row_index" "column"] 1])
 ("click" [["window_name" "object_name"] 0])
 ("closewindow" [["window_name"] 1])
 ("comboselect" [["window_name" "object_name" "item_name"] 0])
 ("comboselectindex" [["window_name" "object_name" "item_index"] 0])
 ("copytext"
  [["window_name" "object_name" "start_position" "end_position"] 1])
 ("cuttext"
  [["window_name" "object_name" "start_position" "end_position"] 1])
 ("decrease" [["window_name" "object_name" "iterations"] 0])
 ("delaycmdexec" [["delay"] 1])
 ("deletetext"
  [["window_name" "object_name" "start_position" "end_position"] 1])
 ("deregisterevent" [["event_name"] 0])
 ("deregisterkbevent" [["keys" "modifiers"] 1])
 ("doesmenuitemexist"
  [["window_name" "object_name" "strict_hierarchy"] 1])
 ("doesrowexist"
  [["window_name" "object_name" "row_text" "partial_match"] 1])
 ("doubleclick" [["window_name" "object_name"] 0])
 ("doubleclickrow" [["window_name" "object_name" "row_text"] 0])
 ("enterstring" [["window_name" "object_name" "data"] 2])
 ("expandtablecell"
  [["window_name" "object_name" "row_index" "column"] 1])
 ("generatekeyevent" [["data"] 0])
 ("generatemouseevent" [["x" "y" "eventType"] 1])
 ("getallitem" [["window_name" "object_name"] 0])
 ("getallstates" [["window_name" "object_name"] 0])
 ("getapplist" [[] 0])
 ("getcellvalue"
  [["window_name" "object_name" "row_index" "column"] 1])
 ("getcharcount" [["window_name" "object_name"] 0])
 ("getchild" [["window_name" "child_name" "role" "parent"] 3])
 ("getcpustat" [["process_name"] 0])
 ("getcursorposition" [["window_name" "object_name"] 0])
 ("getlastlog" [[] 0])
 ("getmax" [["window_name" "object_name"] 0])
 ("getmaxvalue" [["window_name" "object_name"] 0])
 ("getmemorystat" [["process_name"] 0])
 ("getmin" [["window_name" "object_name"] 0])
 ("getminincrement" [["window_name" "object_name"] 0])
 ("getminvalue" [["window_name" "object_name"] 0])
 ("getobjectinfo" [["window_name" "object_name"] 0])
 ("getobjectlist" [["window_name"] 0])
 ("getobjectnameatcoords" [["wait_time"] 1])
 ("getobjectproperty" [["window_name" "object_name" "prop"] 0])
 ("getobjectsize" [["window_name" "object_name"] 0])
 ("getpanelchildcount" [["window_name" "object_name"] 0])
 ("getrowcount" [["window_name" "object_name"] 0])
 ("getslidervalue" [["window_name" "object_name"] 0])
 ("getstatusbartext" [["window_name" "object_name"] 0])
 ("gettabcount" [["window_name" "object_name"] 0])
 ("gettablerowindex" [["window_name" "object_name" "row_text"] 0])
 ("gettabname" [["window_name" "object_name" "tab_index"] 0])
 ("gettextvalue"
  [["window_name" "object_name" "startPosition" "endPosition"] 2])
 ("getvalue" [["window_name" "object_name"] 0])
 ("getwindowlist" [[] 0])
 ("getwindowsize" [["window_name"] 0])
 ("grabfocus" [["window_name" "object_name"] 0])
 ("guiexist" [["window_name" "object_name"] 1])
 ("handletablecell" [[] 0])
 ("hasstate" [["window_name" "object_name" "state" "guiTimeOut"] 1])
 ("hidelist" [["window_name" "object_name"] 0])
 ("imagecapture" [["window_name" "x" "y" "width" "height"] 5])
 ("increase" [["window_name" "object_name" "iterations"] 0])
 ("invokemenu" [["window_name" "object_name"] 0])
 ("isalive" [[] 0])
 ("ischildindexselected"
  [["window_name" "object_name" "item_index"] 0])
 ("ischildselected" [["window_name" "object_name" "item_name"] 0])
 ("istextstateenabled" [["window_name" "object_name"] 0])
 ("keypress" [["data"] 0])
 ("keyrelease" [["data"] 0])
 ("launchapp" [["cmd" "args" "delay" "env" "lang"] 4])
 ("listsubmenus" [["window_name" "object_name"] 0])
 ("maximizewindow" [["window_name"] 1])
 ("menucheck" [["window_name" "object_name"] 0])
 ("menuitemenabled" [["window_name" "object_name"] 0])
 ("menuuncheck" [["window_name" "object_name"] 0])
 ("minimizewindow" [["window_name"] 1])
 ("mouseleftclick" [["window_name" "object_name"] 0])
 ("mousemove" [["window_name" "object_name"] 0])
 ("mouserightclick" [["window_name" "object_name"] 0])
 ("objectexist" [["window_name" "object_name"] 0])
 ("onedown" [["window_name" "object_name" "iterations"] 0])
 ("oneleft" [["window_name" "object_name" "iterations"] 0])
 ("oneright" [["window_name" "object_name" "iterations"] 0])
 ("oneup" [["window_name" "object_name" "iterations"] 0])
 ("onwindowcreate" [["window_name"] 0])
 ("pastetext" [["window_name" "object_name" "position"] 1])
 ("poll_events" [[] 0])
 ("press" [["window_name" "object_name"] 0])
 ("registerevent" [["event_name"] 0])
 ("registerkbevent" [["keys" "modifiers"] 1])
 ("remap" [["window_name"] 0])
 ("removecallback" [["window_name"] 0])
 ("rightclick" [["window_name" "object_name" "row_text"] 0])
 ("scrolldown" [["window_name" "object_name"] 0])
 ("scrollleft" [["window_name" "object_name"] 0])
 ("scrollright" [["window_name" "object_name"] 0])
 ("scrollup" [["window_name" "object_name"] 0])
 ("selectall" [["window_name" "object_name"] 0])
 ("selecteditemcount" [["window_name" "object_name"] 0])
 ("selectindex" [["window_name" "object_name" "item_index"] 0])
 ("selectitem" [["window_name" "object_name" "item_name"] 0])
 ("selectlastrow" [["window_name" "object_name"] 0])
 ("selectmenuitem" [["window_name" "object_name"] 0])
 ("selectpanel" [["window_name" "object_name" "index"] 0])
 ("selectpanelindex" [["window_name" "object_name" "index"] 0])
 ("selectpanelname" [["window_name" "object_name" "name"] 0])
 ("selectrow" [["window_name" "object_name" "row_text"] 0])
 ("selectrowindex" [["window_name" "object_name" "row_index"] 0])
 ("selectrowpartialmatch" [["window_name" "object_name" "row_text"] 0])
 ("selecttab" [["window_name" "object_name" "tab_name"] 0])
 ("selecttabindex" [["window_name" "object_name" "tab_index"] 0])
 ("setcellvalue"
  [["window_name" "object_name" "row_index" "column" "data"] 2])
 ("setcursorposition"
  [["window_name" "object_name" "cursor_position"] 0])
 ("setlocale" [["locale_str"] 0])
 ("setmax" [["window_name" "object_name"] 0])
 ("setmin" [["window_name" "object_name"] 0])
 ("settextvalue" [["window_name" "object_name" "data"] 0])
 ("setvalue" [["window_name" "object_name" "data"] 0])
 ("showlist" [["window_name" "object_name"] 0])
 ("simulatemousemove"
  [["source_x" "source_y" "dest_x" "dest_y" "delay"] 1])
 ("singleclickrow" [["window_name" "object_name" "row_text"] 0])
 ("startprocessmonitor" [["process_name" "interval"] 1])
 ("stateenabled" [["window_name" "object_name"] 0])
 ("stopprocessmonitor" [["process_name"] 0])
 ("uncheck" [["window_name" "object_name"] 0])
 ("uncheckrow" [["window_name" "object_name" "row_index" "column"] 1])
 ("unhandletablecell" [[] 0])
 ("unmaximizewindow" [["window_name"] 1])
 ("unminimizewindow" [["window_name"] 1])
 ("unselectall" [["window_name" "object_name"] 0])
 ("unselectindex" [["window_name" "object_name" "item_index"] 0])
 ("unselectitem" [["window_name" "object_name" "item_name"] 0])
 ("verifycheck" [["window_name" "object_name"] 0])
 ("verifydropdown" [["window_name" "object_name"] 0])
 ("verifyhidelist" [["window_name" "object_name"] 0])
 ("verifymenucheck" [["window_name" "object_name"] 0])
 ("verifymenuuncheck" [["window_name" "object_name"] 0])
 ("verifypartialmatch"
  [["window_name" "object_name" "partial_text"] 0])
 ("verifypartialtablecell"
  [["window_name" "object_name" "row_index" "column_index" "row_text"]
   0])
 ("verifypushbutton" [["window_name" "object_name"] 0])
 ("verifyscrollbarhorizontal" [["window_name" "object_name"] 0])
 ("verifyscrollbarvertical" [["window_name" "object_name"] 0])
 ("verifyselect" [["window_name" "object_name" "item_name"] 0])
 ("verifysettext" [["window_name" "object_name" "text"] 0])
 ("verifysetvalue" [["window_name" "object_name" "data"] 0])
 ("verifyshowlist" [["window_name" "object_name"] 0])
 ("verifysliderhorizontal" [["window_name" "object_name"] 0])
 ("verifyslidervertical" [["window_name" "object_name"] 0])
 ("verifytablecell"
  [["window_name" "object_name" "row_index" "column_index" "row_text"]
   0])
 ("verifytabname" [["window_name" "object_name" "tab_name"] 0])
 ("verifytoggled" [["window_name" "object_name"] 0])
 ("verifyuncheck" [["window_name" "object_name"] 0])
 ("wait" [["timeout"] 1])
 ("waittillguiexist"
  [["window_name" "object_name" "guiTimeOut" "state"] 3])
 ("waittillguinotexist" [["window_name" "object_name" "guiTimeOut"] 2])
 ("windowuptime" [["window_name"] 0])]
